@@ -24,6 +24,7 @@ def register_definition(
 			default_value=Utils.DataDefinitionDefaultValue(),
 			examples=None,
 			nullable=False,
+			deprecated=False,
 			is_internal=False,
 			rules=[],
 			meta=None,
@@ -42,6 +43,7 @@ def register_definition(
 			default_value=default_value,
 			examples=examples,
 			nullable=nullable,
+			deprecated=deprecated,
 			is_internal=is_internal,
 			rules=rules,
 			meta=meta,
