@@ -38,6 +38,7 @@ class Definition:
 				default_value,
 				examples,
 				nullable,
+				deprecated,
 				is_internal,
 				rules,
 				meta,
@@ -51,6 +52,7 @@ class Definition:
 		self.default_value = default_value
 		self.examples = examples
 		self.nullable = nullable
+		self.deprecated = deprecated
 		self.is_internal = is_internal
 		self.dependencies = set()
 		self.rules = rules
@@ -385,6 +387,7 @@ class Index:
 				default_value,
 				examples,
 				nullable,
+				deprecated,
 				is_internal,
 				rules,
 				meta,
@@ -399,6 +402,7 @@ class Index:
 				default_value=default_value,
 				examples=examples,
 				nullable=nullable,
+				deprecated=deprecated,
 				is_internal=is_internal,
 				rules=rules,
 				meta=meta,
