@@ -5,9 +5,7 @@ class Index(dict):
 	def __getattr__(self, name):
 		resolved = Config.parameter_name_resolver.resolve(self, name)
 		if resolved is None:
-			if not Config.parameter_name_resolver.is_nullable(self, name):
-				raise Config.exception_factory.create_input_error(name, 'Unresolved name.')
-			return None
+			raise Config.exception_factory.create_input_error(name, 'Unresolved name.')
 		result = self[resolved]
 		return result
 
